c-apidocs
=========

API Documentation Utilities

This project provides utilities to generate API documentation for C libraries,
as well as project documentation.

### Project

 * **Website**: <https://c-util.github.io/c-apidocs>
 * **Bug Tracker**: <https://github.com/c-util/c-apidocs/issues>

### Requirements

The requirements for this project are:

 * `hawkmoth >= 0.20`
 * `python >= 3.8`

### Repository:

 - **web**:   <https://github.com/c-util/c-apidocs>
 - **https**: `https://github.com/c-util/c-apidocs.git`
 - **ssh**:   `git@github.com:c-util/c-apidocs.git`

### License:

 - **Apache-2.0** OR **LGPL-2.1-or-later**
 - See AUTHORS file for details.
